@@ -1,7 +1,7 @@
 // qjackctlConnect.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1169,8 +1169,11 @@ int qjackctlConnectorView::itemY ( QTreeWidgetItem *pItem ) const
 
 // Draw visible port connection relation lines
 void qjackctlConnectorView::drawConnectionLine ( QPainter *pPainter,
-	int x1, int y1, int x2, int y2, int h1, int h2 )
+	int x1, int y1, int x2, int y2, int h1, int h2, const QPen& pen )
 {
+	// Set apropriate pen...
+	pPainter->setPen(pen);
+
 	// Account for list view headers.
 	y1 += h1;
 	y2 += h2;
@@ -1191,7 +1194,7 @@ void qjackctlConnectorView::drawConnectionLine ( QPainter *pPainter,
 		QPainterPath path;
 		path.moveTo(spline.at(0));
 		path.cubicTo(spline.at(1), spline.at(2), spline.at(3));
-		pPainter->strokePath(path, pPainter->pen());
+		pPainter->strokePath(path, pen);
 	}
 	else pPainter->drawLine(x1 + 4, y1, x2 - 4, y2);
 
@@ -1222,7 +1225,10 @@ void qjackctlConnectorView::paintEvent ( QPaintEvent * )
 	int x2, y2, h2;
 	int i, rgb[3] = { 0x33, 0x66, 0x99 };
 
-	// Inline adaptive to draker background themes...
+	// Draw all lines anti-aliased...
+	painter.setRenderHint(QPainter::Antialiasing);
+
+	// Inline adaptive to darker background themes...
 	if (QWidget::palette().window().color().value() < 0x7f)
 		for (i = 0; i < 3; ++i) rgb[i] += 0x33;
 
@@ -1245,7 +1251,7 @@ void qjackctlConnectorView::paintEvent ( QPaintEvent * )
 			continue;
 		// Set new connector color.
 		++i;
-		painter.setPen(QColor(rgb[i % 3], rgb[(i / 3) % 3], rgb[(i / 9) % 3]));
+		QPen pen(QColor(rgb[i % 3], rgb[(i / 3) % 3], rgb[(i / 9) % 3]));
 		// For each port item
 		const int iChildCount = pOClient->childCount();
 		for (int iChild = 0; iChild < iChildCount; ++iChild) {
@@ -1255,6 +1261,8 @@ void qjackctlConnectorView::paintEvent ( QPaintEvent * )
 			qjackctlPortItem *pOPort
 				= static_cast<qjackctlPortItem *> (pChild);
 			if (pOPort) {
+				// Set proposed line width...
+				const int w1 = (pOPort->isHilite() ? 2 : 1);
 				// Get starting connector arrow coordinates.
 				y1 = itemY(pOPort) + (yo - yc);
 				// Get port connections...
@@ -1264,7 +1272,8 @@ void qjackctlConnectorView::paintEvent ( QPaintEvent * )
 					// Obviously, should be a connection
 					// from pOPort to pIPort items:
 					y2 = itemY(pIPort) + (yi - yc);
-					drawConnectionLine(&painter, x1, y1, x2, y2, h1, h2);
+					pen.setWidth(pIPort->isHilite() ? 2 : w1);
+					drawConnectionLine(&painter, x1, y1, x2, y2, h1, h2, pen);
 				}
 			}
 		}
@@ -1328,6 +1337,8 @@ qjackctlConnectView::qjackctlConnectView ( QWidget *pParent )
 	m_bBezierLines = false;
 	m_iIconSize    = 0;
 
+	QSplitter::setHandleWidth(2);
+
 	QObject::connect(m_pOListView, SIGNAL(itemExpanded(QTreeWidgetItem *)),
 		m_pConnectorView, SLOT(contentsChanged()));
 	QObject::connect(m_pOListView, SIGNAL(itemCollapsed(QTreeWidgetItem *)),
@@ -1474,7 +1485,7 @@ qjackctlConnect::~qjackctlConnect (void)
 	m_pOClientList = NULL;
 	m_pIClientList = NULL;
 
-	m_pConnectView->ConnectorView()->update();
+	m_pConnectView->connectorView()->update();
 }
 
 
@@ -1548,6 +1559,7 @@ bool qjackctlConnect::canConnectSelectedEx (void)
 	// Take this opportunity to highlight any current selections.
 	m_pOClientList->hiliteClientPorts();
 	m_pIClientList->hiliteClientPorts();
+	m_pConnectView->connectorView()->update();
 
 	// Now with our predicate work...
 	QTreeWidgetItem *pOItem = (m_pOClientList->listView())->currentItem();
@@ -1621,7 +1633,7 @@ bool qjackctlConnect::connectSelected (void)
 		endMutex();
 	}
 
-	m_pConnectView->ConnectorView()->update();
+	m_pConnectView->connectorView()->update();
 
 	if (bResult)
 		emit connectChanged();
@@ -1775,7 +1787,7 @@ bool qjackctlConnect::disconnectSelected (void)
 		endMutex();
 	}
 
-	m_pConnectView->ConnectorView()->update();
+	m_pConnectView->connectorView()->update();
 
 	if (bResult)
 		emit connectChanged();
@@ -1890,7 +1902,7 @@ bool qjackctlConnect::disconnectAll (void)
 		endMutex();
 	}
 
-	m_pConnectView->ConnectorView()->update();
+	m_pConnectView->connectorView()->update();
 
 	if (bResult)
 		emit connectChanged();
@@ -1922,7 +1934,7 @@ void qjackctlConnect::expandAll (void)
 {
 	(m_pOClientList->listView())->expandAll();
 	(m_pIClientList->listView())->expandAll();
-	(m_pConnectView->ConnectorView())->update();
+	(m_pConnectView->connectorView())->update();
 }
 
 
@@ -1951,7 +1963,7 @@ void qjackctlConnect::updateContents ( bool bClear )
 		endMutex();
 	}
 
-	(m_pConnectView->ConnectorView())->update();
+	(m_pConnectView->connectorView())->update();
 
 	if (!bClear && iDirtyCount > 0)
 		emit connectChanged();
