@@ -1,7 +1,7 @@
 // qjackctlConnect.h
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -343,7 +343,7 @@ public:
 	// Default destructor.
 	~qjackctlConnectorView();
 
-public slots:
+protected slots:
 
 	// Useful slots (should this be protected?).
 	void contentsChanged();
@@ -363,7 +363,7 @@ private:
 
 	// Drawing methods.
 	void drawConnectionLine(QPainter *pPainter,
-		int x1, int y1, int x2, int y2, int h1, int h2);
+		int x1, int y1, int x2, int y2, int h1, int h2, const QPen& pen);
 
 	// Local instance variables.
 	qjackctlConnectView *m_pConnectView;
@@ -389,7 +389,7 @@ public:
 		{ return m_pOListView; }
 	qjackctlClientListView *IListView() const
 		{ return m_pIListView; }
-	qjackctlConnectorView  *ConnectorView() const
+	qjackctlConnectorView  *connectorView() const
 		{ return m_pConnectorView; }
 
 	// Connections object binding methods.
