@@ -1,7 +1,7 @@
 // qjackctlPatchbay.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -1087,6 +1087,9 @@ void qjackctlPatchworkView::paintEvent ( QPaintEvent * )
 	int x2, y2, h2;
 	int i, rgb[3] = { 0x99, 0x66, 0x33 };
 
+	// Draw all lines anti-aliased...
+	painter.setRenderHint(QPainter::Antialiasing);
+
 	// Inline adaptive to darker background themes...
 	if (QWidget::palette().window().color().value() < 0x7f)
 		for (i = 0; i < 3; ++i) rgb[i] += 0x33;
@@ -1186,6 +1189,8 @@ qjackctlPatchbayView::qjackctlPatchbayView ( QWidget *pParent )
 
 	m_bBezierLines = false;
 
+	QSplitter::setHandleWidth(2);
+
 	QObject::connect(m_pOListView, SIGNAL(itemExpanded(QTreeWidgetItem *)),
 		m_pPatchworkView, SLOT(contentsChanged()));
 	QObject::connect(m_pOListView, SIGNAL(itemCollapsed(QTreeWidgetItem *)),
