@@ -1,7 +1,7 @@
 // qjackctlSetup.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -28,6 +28,7 @@
 
 #include <QTimer>
 #include <QTextStream>
+#include <QFileInfo>
 
 
 // Constructor.
@@ -87,6 +88,8 @@ void qjackctlSetup::loadSetup (void)
 	sXrunRegex               = m_settings.value("/XrunRegex", "xrun of at least ([0-9|\\.]+) msecs").toString();
 	bActivePatchbay          = m_settings.value("/ActivePatchbay", false).toBool();
 	sActivePatchbayPath      = m_settings.value("/ActivePatchbayPath").toString();
+	bActivePatchbayReset     = m_settings.value("/ActivePatchbayReset", false).toBool();
+	bQueryDisconnect         = m_settings.value("/QueryDisconnect", true).toBool();
 #ifdef CONFIG_AUTO_REFRESH
 	bAutoRefresh             = m_settings.value("/AutoRefresh", false).toBool();
 	iTimeRefresh             = m_settings.value("/TimeRefresh", 10).toInt();
@@ -110,6 +113,7 @@ void qjackctlSetup::loadSetup (void)
 	bQueryClose              = m_settings.value("/QueryClose", true).toBool();
 	bKeepOnTop               = m_settings.value("/KeepOnTop", false).toBool();
 	bSystemTray              = m_settings.value("/SystemTray", false).toBool();
+	bSystemTrayQueryClose    = m_settings.value("/SystemTrayQueryClose", true).toBool();
 	bStartMinimized          = m_settings.value("/StartMinimized", false).toBool();
 	bDelayedSetup            = m_settings.value("/DelayedSetup", false).toBool();
 	bServerConfig            = m_settings.value("/ServerConfig", true).toBool();
@@ -142,7 +146,8 @@ void qjackctlSetup::loadSetup (void)
 		QString sItem = m_settings.value(sPrefix.arg(++i)).toString();
 		if (sItem.isEmpty())
 			break;
-		patchbays.append(sItem);
+		if (QFileInfo(sItem).exists())
+			patchbays.append(sItem);
 	}
 	m_settings.endGroup();
 
@@ -154,7 +159,8 @@ void qjackctlSetup::loadSetup (void)
 		QString sItem = m_settings.value(sPrefix.arg(++i)).toString();
 		if (sItem.isEmpty())
 			break;
-		sessionDirs.append(sItem);
+		if (QFileInfo(sItem).isDir())
+			sessionDirs.append(sItem);
 	}
 	m_settings.endGroup();
 }
@@ -199,6 +205,8 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/XrunRegex",               sXrunRegex);
 	m_settings.setValue("/ActivePatchbay",          bActivePatchbay);
 	m_settings.setValue("/ActivePatchbayPath",      sActivePatchbayPath);
+	m_settings.setValue("/ActivePatchbayReset",     bActivePatchbayReset);
+	m_settings.setValue("/QueryDisconnect",         bQueryDisconnect);
 #ifdef CONFIG_AUTO_REFRESH
 	m_settings.setValue("/AutoRefresh",             bAutoRefresh);
 	m_settings.setValue("/TimeRefresh",             iTimeRefresh);
@@ -222,6 +230,7 @@ void qjackctlSetup::saveSetup (void)
 	m_settings.setValue("/QueryClose",              bQueryClose);
 	m_settings.setValue("/KeepOnTop",               bKeepOnTop);
 	m_settings.setValue("/SystemTray",              bSystemTray);
+	m_settings.setValue("/SystemTrayQueryClose",    bSystemTrayQueryClose);
 	m_settings.setValue("/StartMinimized",          bStartMinimized);
 	m_settings.setValue("/DelayedSetup",            bDelayedSetup);
 	m_settings.setValue("/ServerConfig",            bServerConfig);
@@ -584,6 +593,8 @@ bool qjackctlSetup::parse_args ( const QStringList& args )
 
 void qjackctlSetup::loadComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 {
+	const bool bBlockSignals = pComboBox->blockSignals(true);
+
 	// Load combobox list from configuration settings file...
 	m_settings.beginGroup("/History/" + pComboBox->objectName());
 
@@ -591,7 +602,7 @@ void qjackctlSetup::loadComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 		pComboBox->setUpdatesEnabled(false);
 		pComboBox->setDuplicatesEnabled(false);
 		pComboBox->clear();
-		for (int i = 0; i < iLimit; i++) {
+		for (int i = 0; i < iLimit; ++i) {
 			const QString& sText = m_settings.value(
 				"/Item" + QString::number(i + 1)).toString();
 			if (sText.isEmpty())
@@ -602,36 +613,43 @@ void qjackctlSetup::loadComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 	}
 
 	m_settings.endGroup();
+
+	pComboBox->blockSignals(bBlockSignals);
 }
 
 
 void qjackctlSetup::saveComboBoxHistory ( QComboBox *pComboBox, int iLimit )
 {
+	const bool bBlockSignals = pComboBox->blockSignals(true);
+
 	// Add current text as latest item...
-	const QString& sCurrentText = pComboBox->currentText();
+	const QString sCurrentText = pComboBox->currentText();
 	int iCount = pComboBox->count();
 	for (int i = 0; i < iCount; i++) {
 		const QString& sText = pComboBox->itemText(i);
 		if (sText == sCurrentText) {
 			pComboBox->removeItem(i);
-			iCount--;
+			--iCount;
 			break;
 		}
 	}
 	while (iCount >= iLimit)
 		pComboBox->removeItem(--iCount);
 	pComboBox->insertItem(0, sCurrentText);
-	iCount++;
+	pComboBox->setCurrentIndex(0);
+	++iCount;
 
 	// Save combobox list to configuration settings file...
 	m_settings.beginGroup("/History/" + pComboBox->objectName());
-	for (int i = 0; i < iCount; i++) {
+	for (int i = 0; i < iCount; ++i) {
 		const QString& sText = pComboBox->itemText(i);
 		if (sText.isEmpty())
 			break;
 		m_settings.setValue("/Item" + QString::number(i + 1), sText);
 	}
 	m_settings.endGroup();
+
+	pComboBox->blockSignals(bBlockSignals);
 }
 
 
