@@ -1,7 +1,7 @@
 // qjackctlSetupForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2014, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2015, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -22,6 +22,8 @@
 #include "qjackctlAbout.h"
 #include "qjackctlSetupForm.h"
 
+#include "qjackctlMainForm.h"
+
 #include "qjackctlSetup.h"
 
 #include <QValidator>
@@ -290,6 +292,12 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.ActivePatchbayPathToolButton,
 		SIGNAL(clicked()),
 		SLOT(browseActivePatchbayPath()));
+	QObject::connect(m_ui.ActivePatchbayResetCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
+	QObject::connect(m_ui.QueryDisconnectCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 #ifdef CONFIG_AUTO_REFRESH
 	QObject::connect(m_ui.AutoRefreshCheckBox,
 		SIGNAL(stateChanged(int)),
@@ -380,6 +388,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.SystemTrayCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.SystemTrayQueryCloseCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.StartMinimizedCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
@@ -392,6 +403,9 @@ qjackctlSetupForm::qjackctlSetupForm (
 	QObject::connect(m_ui.SingletonCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(optionsChanged()));
+	QObject::connect(m_ui.ServerConfigCheckBox,
+		SIGNAL(stateChanged(int)),
+		SLOT(optionsChanged()));
 	QObject::connect(m_ui.ServerConfigNameComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(optionsChanged()));
@@ -508,6 +522,8 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.ActivePatchbayCheckBox->setChecked(m_pSetup->bActivePatchbay);
 	setComboBoxCurrentText(m_ui.ActivePatchbayPathComboBox,
 		m_pSetup->sActivePatchbayPath);
+	m_ui.ActivePatchbayResetCheckBox->setChecked(m_pSetup->bActivePatchbayReset);
+	m_ui.QueryDisconnectCheckBox->setChecked(m_pSetup->bQueryDisconnect);
 #ifdef CONFIG_AUTO_REFRESH
 	m_ui.AutoRefreshCheckBox->setChecked(m_pSetup->bAutoRefresh);
 	setComboBoxCurrentText(m_ui.TimeRefreshComboBox,
@@ -594,6 +610,7 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 	m_ui.QueryCloseCheckBox->setChecked(m_pSetup->bQueryClose);
 	m_ui.KeepOnTopCheckBox->setChecked(m_pSetup->bKeepOnTop);
 	m_ui.SystemTrayCheckBox->setChecked(m_pSetup->bSystemTray);
+	m_ui.SystemTrayQueryCloseCheckBox->setChecked(m_pSetup->bSystemTrayQueryClose);
 	m_ui.StartMinimizedCheckBox->setChecked(m_pSetup->bStartMinimized);
 	m_ui.DelayedSetupCheckBox->setChecked(m_pSetup->bDelayedSetup);
 	m_ui.SingletonCheckBox->setChecked(m_pSetup->bSingleton);
@@ -618,6 +635,8 @@ void qjackctlSetupForm::setup ( qjackctlSetup *pSetup )
 #ifndef CONFIG_SYSTEM_TRAY
 	m_ui.SystemTrayCheckBox->setChecked(false);
 	m_ui.SystemTrayCheckBox->setEnabled(false);
+	m_ui.ShowSystemTrayMessageCheckBox->setChecked(false);
+	m_ui.ShowSystemTrayMessageCheckBox->setEnabled(false);
 	m_ui.StartMinimizedCheckBox->setChecked(false);
 	m_ui.StartMinimizedCheckBox->setEnabled(false);
 #endif
@@ -1096,6 +1115,8 @@ void qjackctlSetupForm::stabilizeForm (void)
 	bEnabled = m_ui.ActivePatchbayCheckBox->isChecked();
 	m_ui.ActivePatchbayPathComboBox->setEnabled(bEnabled);
 	m_ui.ActivePatchbayPathToolButton->setEnabled(bEnabled);
+	m_ui.ActivePatchbayResetCheckBox->setEnabled(bEnabled);
+	m_ui.QueryDisconnectCheckBox->setEnabled(bEnabled);
 	if (bEnabled && bValid) {
 		const QString& sPath = m_ui.ActivePatchbayPathComboBox->currentText();
 		bValid = (!sPath.isEmpty() && QFileInfo(sPath).exists());
@@ -1129,8 +1150,9 @@ void qjackctlSetupForm::stabilizeForm (void)
 #endif
 #endif
 
-	m_ui.StartMinimizedCheckBox->setEnabled(
-		m_ui.SystemTrayCheckBox->isChecked());
+	bEnabled = m_ui.SystemTrayCheckBox->isChecked();
+	m_ui.SystemTrayQueryCloseCheckBox->setEnabled(bEnabled);
+	m_ui.StartMinimizedCheckBox->setEnabled(bEnabled);
 
 	m_ui.StopJackCheckBox->setEnabled(
 		m_ui.DBusEnabledCheckBox->isChecked());
@@ -1493,7 +1515,42 @@ void qjackctlSetupForm::optionsChanged (void)
 // Accept settings (OK button slot).
 void qjackctlSetupForm::accept (void)
 {
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm == NULL)
+		return;
+
 	if (m_iDirtySettings > 0 || m_iDirtyOptions > 0) {
+		// To track down deferred or immediate changes.
+		const bool    bOldMessagesLog         = m_pSetup->bMessagesLog;
+		const QString sOldMessagesLogPath     = m_pSetup->sMessagesLogPath;
+		const QString sOldMessagesFont        = m_pSetup->sMessagesFont;
+		const QString sOldDisplayFont1        = m_pSetup->sDisplayFont1;
+		const QString sOldDisplayFont2        = m_pSetup->sDisplayFont2;
+		const QString sOldConnectionsFont     = m_pSetup->sConnectionsFont;
+		const int     iOldConnectionsIconSize = m_pSetup->iConnectionsIconSize;
+		const int     iOldJackClientPortAlias = m_pSetup->iJackClientPortAlias;
+		const bool    bOldJackClientPortMetadata = m_pSetup->bJackClientPortMetadata;
+		const int     iOldTimeDisplay         = m_pSetup->iTimeDisplay;
+		const int     iOldTimeFormat          = m_pSetup->iTimeFormat;
+		const bool    bOldDisplayEffect       = m_pSetup->bDisplayEffect;
+		const bool    bOldActivePatchbay      = m_pSetup->bActivePatchbay;
+		const QString sOldActivePatchbayPath  = m_pSetup->sActivePatchbayPath;
+		const bool    bOldStdoutCapture       = m_pSetup->bStdoutCapture;
+		const bool    bOldKeepOnTop           = m_pSetup->bKeepOnTop;
+		const bool    bOldSystemTray          = m_pSetup->bSystemTray;
+		const bool    bOldDelayedSetup        = m_pSetup->bDelayedSetup;
+		const int     bOldMessagesLimit       = m_pSetup->bMessagesLimit;
+		const int     iOldMessagesLimitLines  = m_pSetup->iMessagesLimitLines;
+		const bool    bOldBezierLines         = m_pSetup->bBezierLines;
+		const bool    bOldAlsaSeqEnabled      = m_pSetup->bAlsaSeqEnabled;
+		const bool    bOldDBusEnabled         = m_pSetup->bDBusEnabled;
+		const bool    bOldAliasesEnabled      = m_pSetup->bAliasesEnabled;
+		const bool    bOldAliasesEditing      = m_pSetup->bAliasesEditing;
+		const bool    bOldLeftButtons         = m_pSetup->bLeftButtons;
+		const bool    bOldRightButtons        = m_pSetup->bRightButtons;
+		const bool    bOldTransportButtons    = m_pSetup->bTransportButtons;
+		const bool    bOldTextLabels          = m_pSetup->bTextLabels;
+		const int     iOldBaseFontSize        = m_pSetup->iBaseFontSize;
 		// Save current preset selection.
 		m_pSetup->sDefPreset = m_ui.PresetComboBox->currentText();
 		// Always save current settings...
@@ -1511,6 +1568,8 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->sXrunRegex               = m_ui.XrunRegexComboBox->currentText();
 		m_pSetup->bActivePatchbay          = m_ui.ActivePatchbayCheckBox->isChecked();
 		m_pSetup->sActivePatchbayPath      = m_ui.ActivePatchbayPathComboBox->currentText();
+		m_pSetup->bActivePatchbayReset     = m_ui.ActivePatchbayResetCheckBox->isChecked();
+		m_pSetup->bQueryDisconnect         = m_ui.QueryDisconnectCheckBox->isChecked();
 #ifdef CONFIG_AUTO_REFRESH
 		m_pSetup->bAutoRefresh             = m_ui.AutoRefreshCheckBox->isChecked();
 		m_pSetup->iTimeRefresh             = m_ui.TimeRefreshComboBox->currentText().toInt();
@@ -1537,6 +1596,7 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bQueryClose              = m_ui.QueryCloseCheckBox->isChecked();
 		m_pSetup->bKeepOnTop               = m_ui.KeepOnTopCheckBox->isChecked();
 		m_pSetup->bSystemTray              = m_ui.SystemTrayCheckBox->isChecked();
+		m_pSetup->bSystemTrayQueryClose    = m_ui.SystemTrayQueryCloseCheckBox->isChecked();
 		m_pSetup->bStartMinimized          = m_ui.StartMinimizedCheckBox->isChecked();
 		m_pSetup->bDelayedSetup            = m_ui.DelayedSetupCheckBox->isChecked();
 		m_pSetup->bSingleton               = m_ui.SingletonCheckBox->isChecked();
@@ -1553,6 +1613,74 @@ void qjackctlSetupForm::accept (void)
 		m_pSetup->bTransportButtons        = !m_ui.TransportButtonsCheckBox->isChecked();
 		m_pSetup->bTextLabels              = !m_ui.TextLabelsCheckBox->isChecked();
 		m_pSetup->iBaseFontSize            = m_ui.BaseFontSizeComboBox->currentText().toInt();
+		// Check wheather something immediate has changed.
+		if (( bOldMessagesLog && !m_pSetup->bMessagesLog) ||
+			(!bOldMessagesLog &&  m_pSetup->bMessagesLog) ||
+			(sOldMessagesLogPath != m_pSetup->sMessagesLogPath))
+			pMainForm->updateMessagesLogging();
+		if (( bOldBezierLines && !m_pSetup->bBezierLines) ||
+			(!bOldBezierLines &&  m_pSetup->bBezierLines))
+			pMainForm->updateBezierLines();
+		if (( bOldDisplayEffect && !m_pSetup->bDisplayEffect) ||
+			(!bOldDisplayEffect &&  m_pSetup->bDisplayEffect))
+			pMainForm->updateDisplayEffect();
+		if (iOldJackClientPortAlias != m_pSetup->iJackClientPortAlias)
+			pMainForm->updateJackClientPortAlias();
+		if (( bOldJackClientPortMetadata && !m_pSetup->bJackClientPortMetadata) ||
+			(!bOldJackClientPortMetadata &&  m_pSetup->bJackClientPortMetadata))
+			pMainForm->updateJackClientPortMetadata();
+		if (iOldConnectionsIconSize != m_pSetup->iConnectionsIconSize)
+			pMainForm->updateConnectionsIconSize();
+		if (sOldConnectionsFont != m_pSetup->sConnectionsFont)
+			pMainForm->updateConnectionsFont();
+		if (sOldMessagesFont != m_pSetup->sMessagesFont)
+			pMainForm->updateMessagesFont();
+		if (( bOldMessagesLimit && !m_pSetup->bMessagesLimit) ||
+			(!bOldMessagesLimit &&  m_pSetup->bMessagesLimit) ||
+			(iOldMessagesLimitLines !=  m_pSetup->iMessagesLimitLines))
+			pMainForm->updateMessagesLimit();
+		if (sOldDisplayFont1 != m_pSetup->sDisplayFont1 ||
+			sOldDisplayFont2 != m_pSetup->sDisplayFont2)
+			pMainForm->updateTimeDisplayFonts();
+		if (iOldTimeDisplay != m_pSetup->iTimeDisplay)
+			pMainForm->updateTimeDisplayToolTips();
+		if (iOldTimeFormat != m_pSetup->iTimeFormat)
+			pMainForm->updateTimeFormat();
+		if ((!bOldActivePatchbay && m_pSetup->bActivePatchbay) ||
+			(sOldActivePatchbayPath != m_pSetup->sActivePatchbayPath))
+			pMainForm->updateActivePatchbay();
+		if (( bOldSystemTray && !m_pSetup->bSystemTray) ||
+			(!bOldSystemTray &&  m_pSetup->bSystemTray))
+			pMainForm->updateSystemTray();
+		if (( bOldAliasesEnabled && !m_pSetup->bAliasesEnabled) ||
+			(!bOldAliasesEnabled &&  m_pSetup->bAliasesEnabled) ||
+			( bOldAliasesEditing && !m_pSetup->bAliasesEditing) ||
+			(!bOldAliasesEditing &&  m_pSetup->bAliasesEditing))
+			pMainForm->updateAliases();
+		if (( bOldLeftButtons  && !m_pSetup->bLeftButtons)  ||
+			(!bOldLeftButtons  &&  m_pSetup->bLeftButtons)  ||
+			( bOldRightButtons && !m_pSetup->bRightButtons) ||
+			(!bOldRightButtons &&  m_pSetup->bRightButtons) ||
+			( bOldTransportButtons && !m_pSetup->bTransportButtons) ||
+			(!bOldTransportButtons &&  m_pSetup->bTransportButtons) ||
+			( bOldTextLabels && !m_pSetup->bTextLabels) ||
+			(!bOldTextLabels &&  m_pSetup->bTextLabels))
+			pMainForm->updateButtons();
+		// Warn if something will be only effective on next run.
+		if (( bOldStdoutCapture  && !m_pSetup->bStdoutCapture)  ||
+			(!bOldStdoutCapture  &&  m_pSetup->bStdoutCapture)  ||
+			( bOldKeepOnTop      && !m_pSetup->bKeepOnTop)      ||
+			(!bOldKeepOnTop      &&  m_pSetup->bKeepOnTop)      ||
+			( bOldDelayedSetup   && !m_pSetup->bDelayedSetup)   ||
+			(!bOldDelayedSetup   &&  m_pSetup->bDelayedSetup)   ||
+			( bOldAlsaSeqEnabled && !m_pSetup->bAlsaSeqEnabled) ||
+			(!bOldAlsaSeqEnabled &&  m_pSetup->bAlsaSeqEnabled) ||
+			( bOldDBusEnabled    && !m_pSetup->bDBusEnabled)    ||
+			(!bOldDBusEnabled    &&  m_pSetup->bDBusEnabled)    ||
+			(iOldBaseFontSize    !=  m_pSetup->iBaseFontSize))
+			pMainForm->showDirtySetupWarning();
+		// If server is currently running, warn user...
+		pMainForm->showDirtySettingsWarning();
 	}
 
 	// Save combobox history...
@@ -1571,6 +1699,10 @@ void qjackctlSetupForm::accept (void)
 	// Save/commit to disk.
 	m_pSetup->saveSetup();
 
+	// Reset dirty flags.
+	m_iDirtySettings = 0;
+	m_iDirtyOptions = 0;
+
 	// Just go with dialog acceptance.
 	QDialog::accept();
 }
@@ -1579,7 +1711,15 @@ void qjackctlSetupForm::accept (void)
 // Reject settings (Cancel button slot).
 void qjackctlSetupForm::reject (void)
 {
-	bool bReject = true;
+	if (queryClose())
+		QDialog::reject();
+}
+
+
+// Check whether we're clear to close.
+bool qjackctlSetupForm::queryClose (void)
+{
+	bool bQueryClose = true;
 
 	// Check if there's any pending changes...
 	if (m_iDirtySettings > 0 || m_iDirtyOptions > 0) {
@@ -1592,16 +1732,52 @@ void qjackctlSetupForm::reject (void)
 			QMessageBox::Cancel)) {
 		case QMessageBox::Apply:
 			accept();
-			return;
+			// Fall thru...
 		case QMessageBox::Discard:
+			// Reset dirty flags...
+			m_iDirtySettings = 0;
+			m_iDirtyOptions = 0;
 			break;
 		default:    // Cancel.
-			bReject = false;
+			bQueryClose = false;
+			break;
 		}
 	}
 
-	if (bReject)
-		QDialog::reject();
+	return bQueryClose;
+}
+
+
+// Notify our parent that we're emerging.
+void qjackctlSetupForm::showEvent ( QShowEvent *pShowEvent )
+{
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->stabilizeForm();
+
+	stabilizeForm();
+
+	QDialog::showEvent(pShowEvent);
+}
+
+// Notify our parent that we're closing.
+void qjackctlSetupForm::hideEvent ( QHideEvent *pHideEvent )
+{
+	QDialog::hideEvent(pHideEvent);
+
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->stabilizeForm();
+}
+
+// Just about to notify main-window that we're closing.
+void qjackctlSetupForm::closeEvent ( QCloseEvent * /*pCloseEvent*/ )
+{
+	QDialog::hide();
+
+	qjackctlMainForm *pMainForm = qjackctlMainForm::getInstance();
+	if (pMainForm)
+		pMainForm->stabilizeForm();
 }
 
 
