@@ -1,7 +1,7 @@
 // qjackctlSocketForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2003-2012, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2003-2013, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -394,11 +394,7 @@ void qjackctlSocketForm::addPlug (void)
 	if (!sPlugName.isEmpty()) {
 		QTreeWidgetItem *pItem = m_ui.PlugListView->currentItem();
 		if (pItem)
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-		#else
-			m_ui.PlugListView->setItemSelected(pItem, false);
-		#endif
 		pItem = new QTreeWidgetItem(m_ui.PlugListView, pItem);
 		if (pItem) {
 			pItem->setText(0, sPlugName);
@@ -415,11 +411,7 @@ void qjackctlSocketForm::addPlug (void)
 			}
 			if (pXpmPlug)
 				pItem->setIcon(0, QIcon(*pXpmPlug));
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-		#else
-			m_ui.PlugListView->setItemSelected(pItem, true);
-		#endif
 			m_ui.PlugListView->setCurrentItem(pItem);
 		}
 		m_ui.PlugNameComboBox->setEditText(QString::null);
@@ -458,18 +450,10 @@ void qjackctlSocketForm::moveUpPlug (void)
 	if (pItem) {
 		int iItem = m_ui.PlugListView->indexOfTopLevelItem(pItem);
 		if (iItem > 0) {
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-		#else
-			m_ui.PlugListView->setItemSelected(pItem, false);
-		#endif
 			pItem = m_ui.PlugListView->takeTopLevelItem(iItem);
 			m_ui.PlugListView->insertTopLevelItem(iItem - 1, pItem);
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-		#else
-			m_ui.PlugListView->setItemSelected(pItem, true);
-		#endif
 			m_ui.PlugListView->setCurrentItem(pItem);
 		}
 	}
@@ -486,18 +470,10 @@ void qjackctlSocketForm::moveDownPlug (void)
 		int iItem = m_ui.PlugListView->indexOfTopLevelItem(pItem);
 		int iItemCount = m_ui.PlugListView->topLevelItemCount();
 		if (iItem < iItemCount - 1) {
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(false);
-		#else
-			m_ui.PlugListView->setItemSelected(pItem, false);
-		#endif
 			pItem = m_ui.PlugListView->takeTopLevelItem(iItem);
 			m_ui.PlugListView->insertTopLevelItem(iItem + 1, pItem);
-		#if QT_VERSION >= 0x040200
 			pItem->setSelected(true);
-		#else
-			m_ui.PlugListView->setItemSelected(pItem, true);
-		#endif
 			m_ui.PlugListView->setCurrentItem(pItem);
 		}
 	}
